@@ -1,5 +1,6 @@
 #include <iostream>
 #include <ctime>
+#include <algorithm>
 
 #include "paths.h"
 
@@ -16,6 +17,23 @@ string split_filename(string str, string type = "dir")
     }
 }
 
+string get_extention(string filename) {
+    string extension = "";
+    string::size_type idx;
+
+    idx = filename.rfind('.');
+
+    if (idx != std::string::npos)
+    {
+        extension = filename.substr(idx + 1);
+    }
+    
+    transform(extension.begin(), extension.end(), extension.begin(),
+        [](unsigned char c) { return std::tolower(c); });
+
+    return extension;
+}
+
 unsigned int FileRead(istream& is, vector <char>& buff) {
     is.read(&buff[0], buff.size());
     return is.gcount();
